@@ -6,18 +6,14 @@ https://docs.djangoproject.com/en/4.0/releases/4.0/#miscellaneous
 from __future__ import annotations
 
 import ast
+from collections.abc import Iterable
 from functools import partial
-from typing import Iterable
 
 from tokenize_rt import Offset
 
-from django_upgrade.ast import ast_start_offset
-from django_upgrade.ast import is_rewritable_import_from
-from django_upgrade.data import Fixer
-from django_upgrade.data import State
-from django_upgrade.data import TokenFunc
-from django_upgrade.tokens import find_and_replace_name
-from django_upgrade.tokens import update_import_names
+from django_upgrade.ast import ast_start_offset, is_rewritable_import_from
+from django_upgrade.data import Fixer, State, TokenFunc
+from django_upgrade.tokens import find_and_replace_name, update_import_names
 
 fixer = Fixer(
     __name__,
@@ -34,7 +30,7 @@ RENAMES = {
 def visit_ImportFrom(
     state: State,
     node: ast.ImportFrom,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if node.module == MODULE and is_rewritable_import_from(node):
         name_map = {}
@@ -43,10 +39,13 @@ def visit_ImportFrom(
                 name_map[alias.name] = RENAMES[alias.name]
 
         if name_map:
-            yield ast_start_offset(node), partial(
-                update_import_names,
-                node=node,
-                name_map=name_map,
+            yield (
+                ast_start_offset(node),
+                partial(
+                    update_import_names,
+                    node=node,
+                    name_map=name_map,
+                ),
             )
 
 
@@ -54,10 +53,11 @@ def visit_ImportFrom(
 def visit_Name(
     state: State,
     node: ast.Name,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (name := node.id) in RENAMES and name in state.from_imports[MODULE]:
         new_name = RENAMES[name]
-        yield ast_start_offset(node), partial(
-            find_and_replace_name, name=name, new=new_name
+        yield (
+            ast_start_offset(node),
+            partial(find_and_replace_name, name=name, new=new_name),
         )
