@@ -7,15 +7,13 @@ https://docs.djangoproject.com/en/4.2/releases/4.2/#miscellaneous
 from __future__ import annotations
 
 import ast
+from collections.abc import Iterable
 from functools import partial
-from typing import Iterable
 
 from tokenize_rt import Offset
 
 from django_upgrade.ast import ast_start_offset
-from django_upgrade.data import Fixer
-from django_upgrade.data import State
-from django_upgrade.data import TokenFunc
+from django_upgrade.data import Fixer, State, TokenFunc
 from django_upgrade.tokens import find_and_replace_name
 
 fixer = Fixer(
@@ -35,7 +33,7 @@ NAMES = {
 def visit_Call(
     state: State,
     node: ast.Call,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         isinstance(func := node.func, ast.Attribute)
@@ -43,6 +41,7 @@ def visit_Call(
         and isinstance(func.value, ast.Name)
         and func.value.id == "self"
     ):
-        yield ast_start_offset(func), partial(
-            find_and_replace_name, name=name, new=NAMES[name]
+        yield (
+            ast_start_offset(func),
+            partial(find_and_replace_name, name=name, new=NAMES[name]),
         )
