@@ -1,34 +1,14 @@
-"""
-- Replace compatibility imports for
-    - `django.core.exceptions.EmptyResultSet`
-    - `django.core.exceptions.FieldDoesNotExist`
-    - `django.forms.utils.pretty_name`
-    - `django.forms.boundfield.BoundField`
-  See https://docs.djangoproject.com/en/3.1/releases/3.1/#id1
-
-- Replace `JSONField` imports:
-  See https://docs.djangoproject.com/en/3.1/releases/3.1/#features-deprecated-in-3-1
-
-- Replace `django.utils.functional.lru_cache` with `functools.lru_cache`
-  Undocumented change
-"""
-
 from __future__ import annotations
 
 import ast
 from collections import defaultdict
-from functools import lru_cache
-from functools import partial
-from typing import Iterable
-from typing import Mapping
+from collections.abc import Iterable, Mapping
+from functools import cache, partial
 
 from tokenize_rt import Offset
 
-from django_upgrade.ast import ast_start_offset
-from django_upgrade.ast import is_rewritable_import_from
-from django_upgrade.data import Fixer
-from django_upgrade.data import State
-from django_upgrade.data import TokenFunc
+from django_upgrade.ast import ast_start_offset, is_rewritable_import_from
+from django_upgrade.data import Fixer, State, TokenFunc
 from django_upgrade.tokens import update_import_modules
 
 fixer = Fixer(
@@ -59,7 +39,7 @@ REPLACEMENTS_EXACT = {
         "django.contrib.staticfiles.templatetags.staticfiles": {
             "static": "django.templatetags.static",
         },
-        "django.core.urlresolvers": {
+        "django.core.urlresolvers": dict.fromkeys(
             # Objects moved from django.core.resolvers to django.urls in
             # Django 1.10:
             # https://github.com/django/django/blob/stable/1.10.x/django/urls/__init__.py
@@ -67,8 +47,7 @@ REPLACEMENTS_EXACT = {
             # 2.0: RegexURLPattern, LocaleRegexURLResolver, RegexURLResolver
             # and LocaleRegexProvider. See:
             # https://github.com/django/django/pull/7482#discussion_r121311884
-            name: "django.urls"
-            for name in (
+            (
                 "NoReverseMatch",
                 "Resolver404",
                 "ResolverMatch",
@@ -87,8 +66,9 @@ REPLACEMENTS_EXACT = {
                 "set_script_prefix",
                 "set_urlconf",
                 "translate_url",
-            )
-        },
+            ),
+            "django.urls",
+        ),
     },
     (1, 11): {
         "django.db.models.fields": {
@@ -108,6 +88,7 @@ REPLACEMENTS_EXACT = {
     (2, 0): {
         "django.utils.functional": {"lru_cache": "functools"},
         "django.utils.decorators": {"ContextDecorator": "contextlib"},
+        "django.http.cookie": {"SimpleCookie": "http.cookies"},
     },
     (3, 1): {
         "django.contrib.postgres.forms": {
@@ -122,6 +103,14 @@ REPLACEMENTS_EXACT = {
             "TRANSLATOR_COMMENT_MARK": "django.utils.translation.template"
         }
     },
+    (6, 0): {
+        "django.contrib.postgres.aggregates": {
+            "StringAgg": "django.db.models",
+        },
+        "django.contrib.postgres.aggregates.general": {
+            "StringAgg": "django.db.models",
+        },
+    },
 }
 REPLACEMENTS_EXCEPT_MIGRATIONS = {
     (3, 1): {
@@ -139,7 +128,7 @@ REPLACEMENTS_EXCEPT_MIGRATIONS = {
 }
 
 
-@lru_cache(maxsize=None)
+@cache
 def _get_replacements(
     version: tuple[int, int], looks_like_migrations_file: bool
 ) -> Mapping[str, dict[str, str]]:
@@ -166,7 +155,7 @@ def _get_replacements(
 def visit_ImportFrom(
     state: State,
     node: ast.ImportFrom,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if not is_rewritable_import_from(node) or node.module is None:
         return
@@ -178,8 +167,11 @@ def visit_ImportFrom(
     if node.module in replacements and any(
         alias.name in replacements[node.module] for alias in node.names
     ):
-        yield ast_start_offset(node), partial(
-            update_import_modules,
-            node=node,
-            module_rewrites=replacements[node.module],
+        yield (
+            ast_start_offset(node),
+            partial(
+                update_import_modules,
+                node=node,
+                module_rewrites=replacements[node.module],
+            ),
         )
