@@ -7,28 +7,24 @@ from __future__ import annotations
 
 import ast
 import re
+from collections.abc import Iterable, MutableMapping
 from functools import partial
-from typing import Iterable
-from typing import MutableMapping
 from weakref import WeakKeyDictionary
 
-from tokenize_rt import Offset
-from tokenize_rt import Token
+from tokenize_rt import Offset, Token
 
-from django_upgrade.ast import ast_start_offset
-from django_upgrade.ast import is_rewritable_import_from
-from django_upgrade.compat import str_removeprefix
-from django_upgrade.compat import str_removesuffix
-from django_upgrade.data import Fixer
-from django_upgrade.data import State
-from django_upgrade.data import TokenFunc
-from django_upgrade.tokens import STRING
-from django_upgrade.tokens import extract_indent
-from django_upgrade.tokens import find
-from django_upgrade.tokens import insert
-from django_upgrade.tokens import replace
-from django_upgrade.tokens import str_repr_matching
-from django_upgrade.tokens import update_import_names
+from django_upgrade.ast import ast_start_offset, is_rewritable_import_from
+from django_upgrade.data import Fixer, State, TokenFunc
+from django_upgrade.tokens import (
+    STRING,
+    extract_indent,
+    find,
+    find_last_token,
+    insert,
+    replace,
+    str_repr_matching,
+    update_import_names,
+)
 
 fixer = Fixer(
     __name__,
@@ -40,27 +36,33 @@ fixer = Fixer(
 def visit_ImportFrom(
     state: State,
     node: ast.ImportFrom,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         node.module == "django.conf.urls"
         and is_rewritable_import_from(node)
         and any(alias.name in ("include", "url") for alias in node.names)
     ):
-        yield ast_start_offset(node), partial(
-            update_django_conf_import,
-            node=node,
-            state=state,
+        yield (
+            ast_start_offset(node),
+            partial(
+                update_django_conf_import,
+                node=node,
+                state=state,
+            ),
         )
     elif (
         node.module == "django.urls"
         and is_rewritable_import_from(node)
         and any(alias.name == "re_path" for alias in node.names)
     ):
-        yield ast_start_offset(node), partial(
-            update_django_urls_import,
-            node=node,
-            state=state,
+        yield (
+            ast_start_offset(node),
+            partial(
+                update_django_urls_import,
+                node=node,
+                state=state,
+            ),
         )
 
 
@@ -90,7 +92,7 @@ def update_django_conf_import(
             tokens,
             i,
             node=node,
-            name_map={name: "" for name in removals},
+            name_map=dict.fromkeys(removals, ""),
         )
         if not re_path_imported:
             joined_names = ", ".join(sorted(added_names))
@@ -136,7 +138,7 @@ def update_django_urls_import(
 def visit_Call(
     state: State,
     node: ast.Call,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if isinstance(node.func, ast.Name):
         if (
@@ -153,11 +155,11 @@ def visit_Call(
             # cannot convert where called with all kwargs as names don't align
             and len(node.args) >= 1
         ):
-            regex_path: str | None = None
+            regex_path: ast.Constant | None = None
             if isinstance(node.args[0], ast.Constant) and isinstance(
                 node.args[0].value, str
             ):
-                regex_path = node.args[0].value
+                regex_path = node.args[0]
 
             include_called = (
                 len(node.args) >= 2
@@ -165,12 +167,15 @@ def visit_Call(
                 and isinstance(node.args[1].func, ast.Name)
                 and node.args[1].func.id == "include"
             )
-            yield ast_start_offset(node), partial(
-                fix_url_call,
-                regex_path=regex_path,
-                state=state,
-                node_name=node_name,
-                include_called=include_called,
+            yield (
+                ast_start_offset(node),
+                partial(
+                    fix_url_call,
+                    regex_path=regex_path,
+                    state=state,
+                    node_name=node_name,
+                    include_called=include_called,
+                ),
             )
 
         elif (
@@ -184,18 +189,21 @@ def fix_url_call(
     tokens: list[Token],
     i: int,
     *,
-    regex_path: str | None,
+    regex_path: ast.Constant | None,
     state: State,
     node_name: str,
     include_called: bool,
 ) -> None:
     new_name = "re_path"
     if regex_path is not None:
-        path = convert_path_syntax(regex_path, include_called)
+        regex_value = regex_path.value
+        assert isinstance(regex_value, str)
+        path = convert_path_syntax(regex_value, include_called)
         if path is not None:
-            string_idx = find(tokens, i, name=STRING)
-            path = str_repr_matching(path, match_quotes=tokens[string_idx].src)
-            replace(tokens, string_idx, src=path)
+            string_start_idx = find(tokens, i, name=STRING)
+            string_end_idx = find_last_token(tokens, string_start_idx, node=regex_path)
+            path = str_repr_matching(path, match_quotes=tokens[string_start_idx].src)
+            tokens[string_start_idx : string_end_idx + 1] = [Token(STRING, path)]
             new_name = "path"
     if new_name != node_name:
         state_added_names.setdefault(state, set()).add(new_name)
@@ -217,13 +225,15 @@ REGEX_TO_CONVERTER = {
 def convert_path_syntax(regex_path: str, include_called: bool) -> str | None:
     if not (regex_path.endswith("$") or include_called):
         return None
-    remaining = str_removeprefix(regex_path, "^")
-    remaining = str_removesuffix(remaining, "$")
+    remaining = regex_path.removeprefix("^")
+    remaining = remaining.removesuffix("$")
     path = ""
     while "(?P<" in remaining:
         prefix, rest = remaining.split("(?P<", 1)
         group, remaining = rest.split(")", 1)
         group_name, group_regex = group.split(">", 1)
+        if not group_name.isidentifier():
+            return None
         try:
             converter = REGEX_TO_CONVERTER[group_regex]
         except KeyError:
@@ -234,10 +244,10 @@ def convert_path_syntax(regex_path: str, include_called: bool) -> str | None:
 
     path += remaining
 
-    dashless_path = path.replace("-", "")
-    if re.escape(dashless_path) != dashless_path:
+    path = re.sub(r"\\\.", ".", path)  # unescape literal dots
+
+    if not re.fullmatch(r"[a-zA-Z0-9_\-./<>:]*", path):
         # path still contains regex special characters
-        # dashes are ignored as they only have meaning in regexes within []
         return None
 
     return path
