@@ -6,15 +6,13 @@ https://docs.djangoproject.com/en/3.2/releases/3.2/#features-deprecated-in-3-2
 from __future__ import annotations
 
 import ast
+from collections.abc import Iterable
 from functools import partial
-from typing import Iterable
 
 from tokenize_rt import Offset
 
 from django_upgrade.ast import ast_start_offset
-from django_upgrade.data import Fixer
-from django_upgrade.data import State
-from django_upgrade.data import TokenFunc
+from django_upgrade.data import Fixer, State, TokenFunc
 from django_upgrade.tokens import replace_argument_names
 
 fixer = Fixer(
@@ -31,7 +29,7 @@ KWARGS = {"whitelist": "allowlist"}
 def visit_Call(
     state: State,
     node: ast.Call,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         (
@@ -47,8 +45,11 @@ def visit_Call(
             and node.func.value.id == "validators"
         )
     ) and any(k.arg in KWARGS for k in node.keywords):
-        yield ast_start_offset(node), partial(
-            replace_argument_names,
-            node=node,
-            arg_map=KWARGS,
+        yield (
+            ast_start_offset(node),
+            partial(
+                replace_argument_names,
+                node=node,
+                arg_map=KWARGS,
+            ),
         )
