@@ -6,15 +6,13 @@ https://docs.djangoproject.com/en/stable/releases/3.2/#deprecated-features-3-2
 from __future__ import annotations
 
 import ast
+from collections.abc import Iterable
 from functools import partial
-from typing import Iterable
 
 from tokenize_rt import Offset
 
 from django_upgrade.ast import ast_start_offset
-from django_upgrade.data import Fixer
-from django_upgrade.data import State
-from django_upgrade.data import TokenFunc
+from django_upgrade.data import Fixer, State, TokenFunc
 from django_upgrade.tokens import replace
 
 fixer = Fixer(
@@ -28,7 +26,7 @@ fixer = Fixer(
 def visit_Assign(
     state: State,
     node: ast.Assign,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         isinstance(parents[-1], ast.ClassDef)
