@@ -6,24 +6,15 @@ https://docs.djangoproject.com/en/stable/releases/1.9/#features-deprecated-in-1-
 from __future__ import annotations
 
 import ast
+from collections.abc import Iterable, MutableMapping
 from functools import partial
-from typing import Iterable
-from typing import MutableMapping
 from weakref import WeakKeyDictionary
 
-from tokenize_rt import Offset
-from tokenize_rt import Token
+from tokenize_rt import Offset, Token
 
-from django_upgrade.ast import ast_start_offset
-from django_upgrade.ast import is_rewritable_import_from
-from django_upgrade.data import Fixer
-from django_upgrade.data import State
-from django_upgrade.data import TokenFunc
-from django_upgrade.tokens import OP
-from django_upgrade.tokens import extract_indent
-from django_upgrade.tokens import find
-from django_upgrade.tokens import insert
-from django_upgrade.tokens import parse_call_args
+from django_upgrade.ast import ast_start_offset, is_rewritable_import_from
+from django_upgrade.data import Fixer, State, TokenFunc
+from django_upgrade.tokens import OP, extract_indent, find, insert, parse_call_args
 
 fixer = Fixer(
     __name__,
@@ -35,17 +26,20 @@ fixer = Fixer(
 def visit_ImportFrom(
     state: State,
     node: ast.ImportFrom,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         node.module == "django.db.models"
         and is_rewritable_import_from(node)
         and any(alias.name in {"ForeignKey", "OneToOneField"} for alias in node.names)
     ):
-        yield ast_start_offset(node), partial(
-            update_django_models_import,
-            node=node,
-            state=state,
+        yield (
+            ast_start_offset(node),
+            partial(
+                update_django_models_import,
+                node=node,
+                state=state,
+            ),
         )
 
 
@@ -70,7 +64,7 @@ def update_django_models_import(
 def visit_Call(
     state: State,
     node: ast.Call,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         (
@@ -92,10 +86,13 @@ def visit_Call(
         and all(kw.arg != "on_delete" for kw in node.keywords)
     ):
         should_update_import[state] = not models_imported
-        yield ast_start_offset(node), partial(
-            add_on_delete_keyword,
-            num_pos_args=len(node.args),
-            models_imported=models_imported,
+        yield (
+            ast_start_offset(node),
+            partial(
+                add_on_delete_keyword,
+                num_pos_args=len(node.args),
+                models_imported=models_imported,
+            ),
         )
 
 
