@@ -6,19 +6,14 @@ https://docs.djangoproject.com/en/3.1/releases/3.1/#django-contrib-auth
 from __future__ import annotations
 
 import ast
+from collections.abc import Iterable
 from functools import partial
-from typing import Iterable
 
-from tokenize_rt import Offset
-from tokenize_rt import Token
+from tokenize_rt import Offset, Token
 
 from django_upgrade.ast import ast_start_offset
-from django_upgrade.data import Fixer
-from django_upgrade.data import State
-from django_upgrade.data import TokenFunc
-from django_upgrade.tokens import CODE
-from django_upgrade.tokens import OP
-from django_upgrade.tokens import find
+from django_upgrade.data import Fixer, State, TokenFunc
+from django_upgrade.tokens import CODE, OP, find
 
 fixer = Fixer(
     __name__,
@@ -34,7 +29,7 @@ NEW_NAME = "PASSWORD_RESET_TIMEOUT"
 def visit_Assign(
     state: State,
     node: ast.Assign,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         len(node.targets) == 1
