@@ -6,22 +6,14 @@ https://docs.djangoproject.com/en/2.2/releases/2.2/#requests-and-responses
 from __future__ import annotations
 
 import ast
-import sys
+from collections.abc import Iterable
 from functools import partial
-from typing import Iterable
 
-from tokenize_rt import Offset
-from tokenize_rt import Token
+from tokenize_rt import Offset, Token
 
 from django_upgrade.ast import ast_start_offset
-from django_upgrade.data import Fixer
-from django_upgrade.data import State
-from django_upgrade.data import TokenFunc
-from django_upgrade.tokens import NAME
-from django_upgrade.tokens import STRING
-from django_upgrade.tokens import find
-from django_upgrade.tokens import replace
-from django_upgrade.tokens import str_repr_matching
+from django_upgrade.data import Fixer, State, TokenFunc
+from django_upgrade.tokens import NAME, STRING, find, replace, str_repr_matching
 
 fixer = Fixer(
     __name__,
@@ -33,7 +25,7 @@ fixer = Fixer(
 def visit_Subscript(
     state: State,
     node: ast.Subscript,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         is_request_or_self_request_meta(node.value)
@@ -42,8 +34,9 @@ def visit_Subscript(
         and (meta_name := extract_constant(node.slice)) is not None
         and (header_name := get_header_name(meta_name)) is not None
     ):
-        yield ast_start_offset(node), partial(
-            rewrite_header_access, header_name=header_name
+        yield (
+            ast_start_offset(node),
+            partial(rewrite_header_access, header_name=header_name),
         )
 
 
@@ -51,7 +44,7 @@ def visit_Subscript(
 def visit_Call(
     state: State,
     node: ast.Call,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         isinstance(node.func, ast.Attribute)
@@ -62,8 +55,9 @@ def visit_Call(
         and isinstance(meta_name := node.args[0].value, str)
         and (header_name := get_header_name(meta_name)) is not None
     ):
-        yield ast_start_offset(node), partial(
-            rewrite_header_access, header_name=header_name
+        yield (
+            ast_start_offset(node),
+            partial(rewrite_header_access, header_name=header_name),
         )
 
 
@@ -71,19 +65,20 @@ def visit_Call(
 def visit_Compare(
     state: State,
     node: ast.Compare,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
-        isinstance(node, ast.Compare)
-        and len(node.ops) == 1
+        len(node.ops) == 1
         and isinstance(node.ops[0], (ast.In, ast.NotIn))
         and len(node.comparators) == 1
         and is_request_or_self_request_meta(node.comparators[0])
         and isinstance(node.left, ast.Constant)
+        and isinstance(node.left.value, str)
         and (header_name := get_header_name(node.left.value)) is not None
     ):
-        yield ast_start_offset(node), partial(
-            rewrite_in_statement, header_name=header_name
+        yield (
+            ast_start_offset(node),
+            partial(rewrite_in_statement, header_name=header_name),
         )
 
 
@@ -103,23 +98,10 @@ def is_request_or_self_request_meta(node: ast.AST) -> bool:
     )
 
 
-if sys.version_info >= (3, 9):
-
-    def extract_constant(node: ast.AST) -> str | None:
-        if isinstance(node, ast.Constant) and isinstance(node.value, str):
-            return node.value
-        return None
-
-else:
-
-    def extract_constant(node: ast.AST) -> str | None:
-        if (
-            isinstance(node, ast.Index)
-            and isinstance(node.value, ast.Constant)
-            and isinstance(node.value.value, str)
-        ):
-            return node.value.value
-        return None
+def extract_constant(node: ast.AST) -> str | None:
+    if isinstance(node, ast.Constant) and isinstance(node.value, str):
+        return node.value
+    return None
 
 
 def get_header_name(meta_name: str) -> str | None:
