@@ -6,22 +6,15 @@ https://docs.djangoproject.com/en/4.2/releases/4.2/#custom-file-storages
 from __future__ import annotations
 
 import ast
+from collections.abc import Iterable, MutableMapping
 from functools import partial
-from typing import Iterable
-from typing import MutableMapping
 from weakref import WeakKeyDictionary
 
-from tokenize_rt import Offset
-from tokenize_rt import Token
+from tokenize_rt import Offset, Token
 
 from django_upgrade.ast import ast_start_offset
-from django_upgrade.data import Fixer
-from django_upgrade.data import State
-from django_upgrade.data import TokenFunc
-from django_upgrade.tokens import STRING
-from django_upgrade.tokens import erase_node
-from django_upgrade.tokens import find
-from django_upgrade.tokens import insert
+from django_upgrade.data import Fixer, State, TokenFunc
+from django_upgrade.tokens import STRING, erase_node, find, insert
 
 fixer = Fixer(
     __name__,
@@ -66,7 +59,7 @@ settings_details: MutableMapping[State, SettingsDetails] = WeakKeyDictionary()
 def visit_ImportFrom(
     state: State,
     node: ast.ImportFrom,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         node.names[0].name == "*"
@@ -83,7 +76,7 @@ def visit_ImportFrom(
 def visit_Assign(
     state: State,
     node: ast.Assign,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         len(node.targets) == 1
@@ -107,8 +100,9 @@ def visit_Assign(
             else:
                 details.nodes[name] = node
 
-                yield ast_start_offset(node), partial(
-                    replace_storages, details=details, name=name, node=node
+                yield (
+                    ast_start_offset(node),
+                    partial(replace_storages, details=details, name=name, node=node),
                 )
 
 
