@@ -6,15 +6,13 @@ https://docs.djangoproject.com/en/4.0/releases/4.0/#localization
 from __future__ import annotations
 
 import ast
+from collections.abc import Iterable
 from functools import partial
-from typing import Iterable
 
 from tokenize_rt import Offset
 
 from django_upgrade.ast import ast_start_offset
-from django_upgrade.data import Fixer
-from django_upgrade.data import State
-from django_upgrade.data import TokenFunc
+from django_upgrade.data import Fixer, State, TokenFunc
 from django_upgrade.tokens import erase_node
 
 fixer = Fixer(
@@ -28,7 +26,7 @@ fixer = Fixer(
 def visit_Assign(
     state: State,
     node: ast.Assign,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         len(node.targets) == 1
@@ -36,6 +34,12 @@ def visit_Assign(
         and node.targets[0].id == "USE_L10N"
         and isinstance(node.value, ast.Constant)
         and node.value.value is True
-        and isinstance(parents[-1], ast.Module)
+        and (
+            isinstance(parents[-1], ast.Module)
+            or (
+                isinstance(parents[-1], ast.ClassDef)
+                and isinstance(parents[-2], ast.Module)
+            )
+        )
     ):
         yield ast_start_offset(node), partial(erase_node, node=node)
