@@ -6,18 +6,14 @@ https://docs.djangoproject.com/en/3.0/releases/3.0/#django-utils-encoding-force-
 from __future__ import annotations
 
 import ast
+from collections.abc import Iterable
 from functools import partial
-from typing import Iterable
 
 from tokenize_rt import Offset
 
-from django_upgrade.ast import ast_start_offset
-from django_upgrade.ast import is_rewritable_import_from
-from django_upgrade.data import Fixer
-from django_upgrade.data import State
-from django_upgrade.data import TokenFunc
-from django_upgrade.tokens import find_and_replace_name
-from django_upgrade.tokens import update_import_names
+from django_upgrade.ast import ast_start_offset, is_rewritable_import_from
+from django_upgrade.data import Fixer, State, TokenFunc
+from django_upgrade.tokens import find_and_replace_name, update_import_names
 
 fixer = Fixer(
     __name__,
@@ -35,11 +31,12 @@ NAMES = {
 def visit_ImportFrom(
     state: State,
     node: ast.ImportFrom,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if node.module == MODULE and is_rewritable_import_from(node):
-        yield ast_start_offset(node), partial(
-            update_import_names, node=node, name_map=NAMES
+        yield (
+            ast_start_offset(node),
+            partial(update_import_names, node=node, name_map=NAMES),
         )
 
 
@@ -47,11 +44,12 @@ def visit_ImportFrom(
 def visit_Name(
     state: State,
     node: ast.Name,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (name := node.id) in NAMES and name in state.from_imports[MODULE]:
-        yield ast_start_offset(node), partial(
-            find_and_replace_name, name=name, new=NAMES[name]
+        yield (
+            ast_start_offset(node),
+            partial(find_and_replace_name, name=name, new=NAMES[name]),
         )
 
 
@@ -59,7 +57,7 @@ def visit_Name(
 def visit_Attribute(
     state: State,
     node: ast.Attribute,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         (name := node.attr) in NAMES
@@ -67,6 +65,7 @@ def visit_Attribute(
         and node.value.id == "encoding"
         and "encoding" in state.from_imports["django.utils"]
     ):
-        yield ast_start_offset(node), partial(
-            find_and_replace_name, name=name, new=NAMES[name]
+        yield (
+            ast_start_offset(node),
+            partial(find_and_replace_name, name=name, new=NAMES[name]),
         )
