@@ -6,18 +6,14 @@ https://docs.djangoproject.com/en/3.0/releases/3.0/#features-deprecated-in-3-0
 from __future__ import annotations
 
 import ast
+from collections.abc import Iterable
 from functools import partial
-from typing import Iterable
 
 from tokenize_rt import Offset
 
-from django_upgrade.ast import ast_start_offset
-from django_upgrade.ast import is_rewritable_import_from
-from django_upgrade.data import Fixer
-from django_upgrade.data import State
-from django_upgrade.data import TokenFunc
-from django_upgrade.tokens import find_and_replace_name
-from django_upgrade.tokens import update_import_names
+from django_upgrade.ast import ast_start_offset, is_rewritable_import_from
+from django_upgrade.data import Fixer, State, TokenFunc
+from django_upgrade.tokens import find_and_replace_name, update_import_names
 
 fixer = Fixer(
     __name__,
@@ -38,15 +34,16 @@ NAME_MAP = {
 def visit_ImportFrom(
     state: State,
     node: ast.ImportFrom,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         node.module == MODULE
         and is_rewritable_import_from(node)
         and any(alias.name in NAME_MAP for alias in node.names)
     ):
-        yield ast_start_offset(node), partial(
-            update_import_names, node=node, name_map=NAME_MAP
+        yield (
+            ast_start_offset(node),
+            partial(update_import_names, node=node, name_map=NAME_MAP),
         )
 
 
@@ -54,11 +51,12 @@ def visit_ImportFrom(
 def visit_Name(
     state: State,
     node: ast.Name,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (name := node.id) in NAME_MAP and name in state.from_imports[MODULE]:
-        yield ast_start_offset(node), partial(
-            find_and_replace_name, name=name, new=NAME_MAP[name]
+        yield (
+            ast_start_offset(node),
+            partial(find_and_replace_name, name=name, new=NAME_MAP[name]),
         )
 
 
@@ -66,7 +64,7 @@ def visit_Name(
 def visit_Attribute(
     state: State,
     node: ast.Attribute,
-    parents: list[ast.AST],
+    parents: tuple[ast.AST, ...],
 ) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
         (name := node.attr) in NAME_MAP
@@ -74,6 +72,7 @@ def visit_Attribute(
         and node.value.id == "translation"
         and "translation" in state.from_imports["django.utils"]
     ):
-        yield ast_start_offset(node), partial(
-            find_and_replace_name, name=name, new=NAME_MAP[name]
+        yield (
+            ast_start_offset(node),
+            partial(find_and_replace_name, name=name, new=NAME_MAP[name]),
         )
